@@ -46,7 +46,7 @@ def seconds_to_timestr(seconds, inverse=False):
             mins, secs = divmod(remainder, 60)
             result = '{:02d}:{:02d}:{:02d}'.format(hours, mins, secs)
         except:
-            result = pd.NaT
+            result = None
     else:
         try:
             hours, mins, seconds = seconds.split(':')
@@ -209,14 +209,14 @@ class Feed(object):
         Read in all the relevant GTFS text files within the directory or 
         ZIP file given by ``path``.
         """
-        zipped = False
         if zipfile.is_zipfile(path):
-            zipped = True
             # Extract to temporary location
             archive = zipfile.ZipFile(path)
             path = path.rstrip('.zip') + '/'
             archive.extractall(path)
+        print('zipped?', zipfile.is_zipfile(path))
 
+        print('hey', path)
         self.path = path 
         self.stops = pd.read_csv(path + 'stops.txt', dtype={'stop_id': str, 
           'stop_code': str})
